==> microprofile-config-tck-2.0-sources.jar: org/eclipse/microprofile/config/tck/broken/ConfigObserver.java <==
/*
 * Copyright (c) 2016-2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.eclipse.microprofile.config.tck.broken;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.context.Initialized;
import javax.enterprise.event.Observes;

import org.eclipse.microprofile.config.inject.ConfigProperty;

/**
 * A bean supporting the {@link MissingValueOnObserverMethodInjectionTest} test that injects a non-existent
 * configuration property in a container lifecycle event observer method.
 *
 * @author <a href="https://about.me/lairdnelson" target="_parent">Laird Nelson</a>
 *
 * @see MissingValueOnObserverMethodInjectionTest
 */
@ApplicationScoped
final class ConfigObserver {

    private ConfigObserver() {
        super();
    }

    private static final void onStartup(@Observes @Initialized(ApplicationScoped.class) final Object event,
            @ConfigProperty(name = "this.property.does.not.exist") final String nonExistentConfigurationPropertyValue) {
    }

}

==> microprofile-config-tck-3.0-sources.jar: org/eclipse/microprofile/config/tck/broken/ConfigObserver.java <==
/*
 * Copyright (c) 2016-2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.eclipse.microprofile.config.tck.broken;

import org.eclipse.microprofile.config.inject.ConfigProperty;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.context.Initialized;
import jakarta.enterprise.event.Observes;

/**
 * A bean supporting the {@link MissingValueOnObserverMethodInjectionTest} test that injects a non-existent
 * configuration property in a container lifecycle event observer method.
 *
 * @author <a href="https://about.me/lairdnelson" target="_parent">Laird Nelson</a>
 *
 * @see MissingValueOnObserverMethodInjectionTest
 */
@ApplicationScoped
final class ConfigObserver {

    private ConfigObserver() {
        super();
    }

    private static final void onStartup(@Observes @Initialized(ApplicationScoped.class) final Object event,
            @ConfigProperty(name = "this.property.does.not.exist") final String nonExistentConfigurationPropertyValue) {
    }

}
